==> wildfly-config-api-0.2.1-sources.jar: org/wildfly/swarm/config/ejb3/subsystem/service/Remote.java <==
package org.wildfly.swarm.config.ejb3.subsystem.service;

import org.wildfly.apigen.invocation.Implicit;
import org.wildfly.apigen.invocation.Address;
import org.wildfly.apigen.invocation.Binding;
import java.util.List;
import org.wildfly.apigen.invocation.Subresource;
import org.wildfly.swarm.config.ejb3.subsystem.service.channelCreationOptions.ChannelCreationOptions;
/**
 * The EJB3 Remote Service
 */
@Address("/subsystem=ejb3/service=remote")
@Implicit
public class Remote {

	private String key;
	private String connectorRef;
	private String threadPoolName;
	private RemoteResources subresources = new RemoteResources();

	public Remote() {
		this.key = "remote";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The name of the connector on which the EJB3 remoting channel is registered
	 */
	@Binding(detypedName = "connector-ref")
	public String connectorRef() {
		return this.connectorRef;
	}

	/**
	 * The name of the connector on which the EJB3 remoting channel is registered
	 */
	public Remote connectorRef(String value) {
		this.connectorRef = value;
		return this;
	}

	/**
	 * The name of the thread pool that handles remote invocations
	 */
	@Binding(detypedName = "thread-pool-name")
	public String threadPoolName() {
		return this.threadPoolName;
	}

	/**
	 * The name of the thread pool that handles remote invocations
	 */
	public Remote threadPoolName(String value) {
		this.threadPoolName = value;
		return this;
	}

	public RemoteResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all ChannelCreationOptions objects to this subresource
	 * @return this
	 * @param value List of ChannelCreationOptions objects.
	 */
	public Remote channelCreationOptions(List<ChannelCreationOptions> value) {
		this.subresources.channelCreationOptions.addAll(value);
		return this;
	}

	/**
	 * Add the ChannelCreationOptions object to the list of subresources
	 * @param value The ChannelCreationOptions to add
	 * @return this
	 */
	public Remote channelCreationOptions(ChannelCreationOptions value) {
		this.subresources.channelCreationOptions.add(value);
		return this;
	}

	/**
	 * Child mutators for Remote
	 */
	public class RemoteResources {
		/**
		 * The options that will be used during the EJB remote channel creation
		 */
		private List<ChannelCreationOptions> channelCreationOptions = new java.util.ArrayList<>();

		/**
		 * Get the list of ChannelCreationOptions resources
		 * @return the list of resources
		 */
		@Subresource
		public List<ChannelCreationOptions> channelCreationOptions() {
			return this.channelCreationOptions;
		}
	}
}

==> wildfly-config-api-0.2.2-sources.jar: org/wildfly/swarm/config/ejb3/subsystem/service/Remote.java <==
package org.wildfly.swarm.config.ejb3.subsystem.service;

import org.wildfly.apigen.invocation.Implicit;
import org.wildfly.apigen.invocation.Address;
import org.wildfly.apigen.invocation.Binding;
import java.util.List;
import org.wildfly.apigen.invocation.Subresource;
import org.wildfly.swarm.config.ejb3.subsystem.service.channelCreationOptions.ChannelCreationOptions;
/**
 * The EJB3 Remote Service
 */
@Address("/subsystem=ejb3/service=remote")
@Implicit
public class Remote<T extends Remote> {

	private String key;
	private String connectorRef;
	private String threadPoolName;
	private RemoteResources subresources = new RemoteResources();

	public Remote() {
		this.key = "remote";
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * The name of the connector on which the EJB3 remoting channel is registered
	 */
	@Binding(detypedName = "connector-ref")
	public String connectorRef() {
		return this.connectorRef;
	}

	/**
	 * The name of the connector on which the EJB3 remoting channel is registered
	 */
	@SuppressWarnings("unchecked")
	public T connectorRef(String value) {
		this.connectorRef = value;
		return (T) this;
	}

	/**
	 * The name of the thread pool that handles remote invocations
	 */
	@Binding(detypedName = "thread-pool-name")
	public String threadPoolName() {
		return this.threadPoolName;
	}

	/**
	 * The name of the thread pool that handles remote invocations
	 */
	@SuppressWarnings("unchecked")
	public T threadPoolName(String value) {
		this.threadPoolName = value;
		return (T) this;
	}

	public RemoteResources subresources() {
		return this.subresources;
	}

	/**
	 * Add all ChannelCreationOptions objects to this subresource
	 * @return this
	 * @param value List of ChannelCreationOptions objects.
	 */
	@SuppressWarnings("unchecked")
	public T channelCreationOptions(List<ChannelCreationOptions> value) {
		this.subresources.channelCreationOptions.addAll(value);
		return (T) this;
	}

	/**
	 * Add the ChannelCreationOptions object to the list of subresources
	 * @param value The ChannelCreationOptions to add
	 * @return this
	 */
	@SuppressWarnings("unchecked")
	public T channelCreationOptions(ChannelCreationOptions value) {
		this.subresources.channelCreationOptions.add(value);
		return (T) this;
	}

	/**
	 * Child mutators for Remote
	 */
	public class RemoteResources {
		/**
		 * The options that will be used during the EJB remote channel creation
		 */
		private List<ChannelCreationOptions> channelCreationOptions = new java.util.ArrayList<>();

		/**
		 * Get the list of ChannelCreationOptions resources
		 * @return the list of resources
		 */
		@Subresource
		public List<ChannelCreationOptions> channelCreationOptions() {
			return this.channelCreationOptions;
		}
	}
}
